summaryrefslogtreecommitdiffstats
path: root/noatun-plugins/oblique/query.h
diff options
context:
space:
mode:
Diffstat (limited to 'noatun-plugins/oblique/query.h')
-rw-r--r--noatun-plugins/oblique/query.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/noatun-plugins/oblique/query.h b/noatun-plugins/oblique/query.h
index 60478ff..15ff361 100644
--- a/noatun-plugins/oblique/query.h
+++ b/noatun-plugins/oblique/query.h
@@ -99,7 +99,7 @@ private:
**/
TQString fuzzify(const TQString &str) const;
/**
* @returns the previous or tqparent of this item (slow)
**/
QueryGroup *previous(Query *query);
QueryGroup *previous(QueryGroup *startWith);
@@ -160,8 +160,8 @@ public:
TQString dbname(Base *base);
private:
- void loadGroup(TQDomElement element, QueryGroup *tqparent=0);
- void saveGroup(TQDomElement &tqparent, QueryGroup *group);
+ void loadGroup(TQDomElement element, QueryGroup *parent=0);
+ void saveGroup(TQDomElement &parent, QueryGroup *group);
void deepCopy(const QueryGroup *from, QueryGroup *toParent);
@@ -99,7 +99,7 @@ private:
TQString fuzzify(const TQString &str) const;
/**
- * @returns the previous or tqparent of this item (slow)
+ * @returns the previous or parent of this item (slow)
**/
QueryGroup *previous(Query *query);